@@ -10,69 +10,53 @@
     FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
 */
 
-/* exported init,buildPrefsWidget */
 'use strict';
 
-const GIRepository = imports.gi.GIRepository;
+import GIRepository from 'gi://GIRepository';
 GIRepository.Repository.prepend_search_path('/usr/lib64/gnome-shell');
 GIRepository.Repository.prepend_library_path('/usr/lib64/gnome-shell');
 
-const GObject = imports.gi.GObject;
-const Gio = imports.gi.Gio;
-const Gtk = imports.gi.Gtk;
-const Gdk = imports.gi.Gdk;
-const Pango = imports.gi.Pango;
+import Adw from 'gi://Adw';
+import GObject from 'gi://GObject';
+import Gio from 'gi://Gio';
+import Gtk from 'gi://Gtk';
+import Gdk from 'gi://Gdk';
+import Pango from 'gi://Pango';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
+import {ExtensionPreferences, gettext as _} from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';
 
-const Domain = imports.gettext.domain(Me.metadata['gettext-domain']);
-const _ = Domain.gettext;
-
-const Lib = Me.imports.convenience;
-const UtilWebcam = Me.imports.utilwebcam;
-const UtilGSP = Me.imports.utilgsp;
-const Settings = Me.imports.settings;
-const UtilExeCmd = Me.imports.utilexecmd;
+import * as Lib from './convenience.js';
+import * as UtilWebcam from './utilwebcam.js';
+import * as UtilGSP from './utilgsp.js';
+import * as Settings from './settings.js';
+import * as UtilExeCmd from './utilexecmd.js';
 
 const EasyScreenCastSettingsWidget = GObject.registerClass({
     GTypeName: 'EasyScreenCast_SettingsWidget',
 }, class EasyScreenCastSettingsWidget extends Gtk.Box {
     /**
-     * Init class
-     *
-     * @param {Array} params parameters
-     * @private
+     * @param {ExtensionPreferences} prefs the prefs instance
      */
-    _init(params) {
-        super._init(params);
+    constructor(prefs) {
+        super();
 
-        this._settings = new Settings.Settings();
-        Lib.debugEnabled = this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY);
+        this._prefs = prefs;
+        this._settings = new Settings.Settings(this._prefs.getSettings());
+        Lib.setDebugEnabled(this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY));
         this.CtrlExe = new UtilExeCmd.ExecuteStuff(this);
-        this.CtrlWebcam = new UtilWebcam.HelperWebcam();
+        this.CtrlWebcam = new UtilWebcam.HelperWebcam(_('Unspecified webcam'));
 
         let cssProvider = new Gtk.CssProvider();
-        cssProvider.load_from_path(`${Me.path}/prefs.css`);
-        if (this._isGtk4()) {
-            Gtk.StyleContext.add_provider_for_display(
-                Gdk.Display.get_default(),
-                cssProvider,
-                Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION);
-        } else {
-            Gtk.StyleContext.add_provider_for_screen(
-                Gdk.Screen.get_default(),
-                cssProvider,
-                Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION);
-        }
+        cssProvider.load_from_path(`${prefs.path}/prefs.css`);
+        Gtk.StyleContext.add_provider_for_display(
+            Gdk.Display.get_default(),
+            cssProvider,
+            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION);
 
         // creates the ui builder and add the main resource file
-        let uiFilePath = `${Me.path}/Options_UI.glade`;
-        if (this._isGtk4()) {
-            uiFilePath = `${Me.path}/Options_UI.glade-gtk4`;
-        }
+        let uiFilePath = `${this._prefs.path}/Options_UI.glade`;
         let builder = new Gtk.Builder();
-        builder.set_translation_domain(Me.metadata['gettext-domain']);
+        builder.set_translation_domain(this._prefs.metadata['gettext-domain']);
 
         if (builder.add_from_file(uiFilePath) === 0) {
             Lib.TalkativeLog(`-^-could not load the ui file: ${uiFilePath}`);
@@ -81,22 +65,13 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
                 vexpand: true,
             });
 
-            if (this._isGtk4()) {
-                this.append(label);
-            } else {
-                this.pack_start(label, true, true, 0);
-            }
+            this.append(label);
         } else {
             Lib.TalkativeLog(`-^-UI file receive and load: ${uiFilePath}`);
 
             // gets the interesting builder objects
             let refBoxMainContainer = builder.get_object('Main_Container');
-            if (this._isGtk4()) {
-                this.append(refBoxMainContainer);
-            } else {
-                // packs the main table
-                this.pack_start(refBoxMainContainer, true, true, 0);
-            }
+            this.append(refBoxMainContainer);
 
             // setup tab options
             this._initTabOptions(this, builder, this._settings._settings);
@@ -143,11 +118,6 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
         }
     }
 
-    _isGtk4() {
-        const gtkVersion = Gtk.get_major_version();
-        return gtkVersion >= 4;
-    }
-
     /**
      * @param {EasyScreenCastSettingsWidget} ctx the prefs/settings widget
      * @param {Gtk.Builder} gtkDB the builder that loaded the UI glade file
@@ -346,9 +316,8 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
         refScaleQuality.set_adjustment(adjustment2);
         refScaleQuality.set_digits(1);
         let ind = 0;
-        for (; ind < 4; ind++) {
+        for (; ind < 4; ind++)
             refScaleQuality.add_mark(ind, Gtk.PositionType.BOTTOM, '');
-        }
 
 
         refScaleQuality.set_value(
@@ -393,10 +362,10 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
 
         // implements image for scale widget
         let refImagePerformance = gtkDB.get_object('img_Performance');
-        refImagePerformance.set_from_file(Lib.getImagePath('Icon_Performance.svg'));
+        refImagePerformance.set_from_file(Lib.getImagePath(this._prefs.dir, 'Icon_Performance.svg'));
 
         let refImageQuality = gtkDB.get_object('img_Quality');
-        refImageQuality.set_from_file(Lib.getImagePath('Icon_Quality.svg'));
+        refImageQuality.set_from_file(Lib.getImagePath(this._prefs.dir, 'Icon_Quality.svg'));
 
         // implements custom GSPipeline option
         let refSwitchCustomGSP = gtkDB.get_object('swt_EnableCustomGSP');
@@ -626,13 +595,12 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
 
         // load file resolution pref and upadte UI
         var tmpRes = this._settings.getOption('i', Settings.FILE_RESOLUTION_TYPE_SETTING_KEY);
-        if (tmpRes < 0) {
+        if (tmpRes < 0)
             refStackFileResolution.set_visible_child_name('native');
-        } else if (tmpRes === 999) {
+        else if (tmpRes === 999)
             refStackFileResolution.set_visible_child_name('custom');
-        } else {
+        else
             refStackFileResolution.set_visible_child_name('preset');
-        }
 
 
         // setup event on stack switcher
@@ -732,9 +700,8 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
                 true,
                 (success, out) => {
                     Lib.TalkativeLog(`-^-CALLBACK sync S: ${success} out: ${out}`);
-                    if (success && out !== '' && out !== undefined) {
+                    if (success && out !== '' && out !== undefined)
                         result = out.replace(/(\n)/g, '');
-                    }
                 },
                 null
             );
@@ -750,9 +717,8 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
                     true,
                     (success, out) => {
                         Lib.TalkativeLog(`-^-CALLBACK sync S: ${success} out: ${out}`);
-                        if (success && out !== '' && out !== undefined) {
+                        if (success && out !== '' && out !== undefined)
                             tmpFolder = out.replace(/(\n)/g, '');
-                        }
                     },
                     null
                 );
@@ -768,48 +734,33 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
             );
         }
 
-        if (this._isGtk4()) {
-            refFilechooserFileFolder.set_label(`Selected: ${tmpFolder}`);
+        refFilechooserFileFolder.set_label(`Selected: ${tmpFolder}`);
 
-            refFilechooserFileFolder.connect('clicked', () => {
-                Lib.TalkativeLog('-^- file chooser button clicked...');
+        refFilechooserFileFolder.connect('clicked', () => {
+            Lib.TalkativeLog('-^- file chooser button clicked...');
 
-                let dialog = new Gtk.FileChooserNative({
-                    'title': 'Select folder',
-                    'transient-for': refFilechooserFileFolder.get_root(),
-                    'action': Gtk.FileChooserAction.SELECT_FOLDER,
-                    'accept-label': 'Ok',
-                    'cancel-label': 'Cancel',
-                });
-                dialog.connect('response', (self, response) => {
-                    if (response === Gtk.ResponseType.ACCEPT) {
-                        var tmpPathFolder = self.get_file().get_path();
-                        Lib.TalkativeLog(`-^-file path get from widget : ${tmpPathFolder}`);
-                        this._settings.setOption(
-                            Settings.FILE_FOLDER_SETTING_KEY,
-                            tmpPathFolder
-                        );
-                        refFilechooserFileFolder.set_label(`Selected: ${tmpPathFolder}`);
-                    }
-                    ctx.fileChooserDialog = null;
-                });
-                dialog.show();
-                ctx.fileChooserDialog = dialog; // keep a reference to the dialog alive
+            let dialog = new Gtk.FileChooserNative({
+                'title': 'Select folder',
+                'transient-for': refFilechooserFileFolder.get_root(),
+                'action': Gtk.FileChooserAction.SELECT_FOLDER,
+                'accept-label': 'Ok',
+                'cancel-label': 'Cancel',
             });
-        } else {
-            refFilechooserFileFolder.set_filename(tmpFolder);
-
-            refFilechooserFileFolder.connect('file_set', self => {
-                var tmpPathFolder = self.get_filename();
-                Lib.TalkativeLog(`-^-file path get from widget : ${tmpPathFolder}`);
-                if (tmpPathFolder !== null) {
+            dialog.connect('response', (self, response) => {
+                if (response === Gtk.ResponseType.ACCEPT) {
+                    var tmpPathFolder = self.get_file().get_path();
+                    Lib.TalkativeLog(`-^-file path get from widget : ${tmpPathFolder}`);
                     this._settings.setOption(
                         Settings.FILE_FOLDER_SETTING_KEY,
                         tmpPathFolder
                     );
+                    refFilechooserFileFolder.set_label(`Selected: ${tmpPathFolder}`);
                 }
+                ctx.fileChooserDialog = null;
             });
-        }
+            dialog.show();
+            ctx.fileChooserDialog = dialog; // keep a reference to the dialog alive
+        });
     }
 
     /**
@@ -834,7 +785,7 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
         this._settings._settings.connect(
             `changed::${Settings.VERBOSE_DEBUG_SETTING_KEY}`,
             () => {
-                Lib.debugEnabled = this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY);
+                Lib.setDebugEnabled(this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY));
             }
         );
 
@@ -972,11 +923,11 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
     _initTabInfo(ctx, gtkDB) {
         // implements info img extension
         let refImageEsc = gtkDB.get_object('img_ESC');
-        refImageEsc.set_from_file(Lib.getImagePath('Icon_Info.png'));
+        refImageEsc.set_from_file(Lib.getImagePath(this._prefs.dir, 'Icon_Info.png'));
 
         // implements info version label
         let refLabelVersion = gtkDB.get_object('lbl_Version');
-        refLabelVersion.set_markup(`${_('Version: ')}<span color="blue">${Me.metadata.version}</span> (${Lib.getFullVersion()})`);
+        refLabelVersion.set_markup(`${_('Version: ')}<span color="blue">${this._prefs.metadata.version}</span> (${Lib.getFullVersion()})`);
     }
 
     /**
@@ -1033,9 +984,8 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
      * @private
      */
     _initializeWebcamHelper() {
-        if (this.CtrlWebcam === null) {
-            this.CtrlWebcam = new UtilWebcam.HelperWebcam();
-        }
+        if (this.CtrlWebcam === null)
+            this.CtrlWebcam = new UtilWebcam.HelperWebcam(_('Unspecified webcam'));
     }
 
     /**
@@ -1048,17 +998,13 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
         let [key, mods] = [0, 0];
 
         if (accel !== null && accel !== undefined) {
-            if (this._isGtk4()) {
-                let ok;
-                [ok, key, mods] = Gtk.accelerator_parse(accel);
+            let ok;
+            [ok, key, mods] = Gtk.accelerator_parse(accel);
 
-                if (ok !== true) {
-                    Lib.TalkativeLog('-^-couldn\'t parse accel');
-                    key = 0;
-                    mods = 0;
-                }
-            } else {
-                [key, mods] = Gtk.accelerator_parse(accel);
+            if (ok !== true) {
+                Lib.TalkativeLog('-^-couldn\'t parse accel');
+                key = 0;
+                mods = 0;
             }
         }
 
@@ -1086,9 +1032,8 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
             this.Ref_stack_Quality.set_visible_child_name('pg_Preset');
 
             var audio = false;
-            if (this._settings.getOption('i', Settings.INPUT_AUDIO_SOURCE_SETTING_KEY) > 0) {
+            if (this._settings.getOption('i', Settings.INPUT_AUDIO_SOURCE_SETTING_KEY) > 0)
                 audio = true;
-            }
 
             this._settings.setOption(
                 Settings.PIPELINE_REC_SETTING_KEY,
@@ -1162,11 +1107,10 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
             [2048, 2560],
             [2160, 3840],
         ];
-        if (index >= 0 && index < arrRes.length) {
+        if (index >= 0 && index < arrRes.length)
             return arrRes[index];
-        } else {
+        else
             return null;
-        }
     }
 
     /**
@@ -1214,24 +1158,27 @@ const EasyScreenCastSettingsWidget = GObject.registerClass({
     }
 });
 
-/**
- *
- */
-function init() {
-    ExtensionUtils.initTranslations();
-}
 
-/**
- * @returns {EasyScreenCastSettingsWidget}
- */
-function buildPrefsWidget() {
-    Lib.TalkativeLog('-^-Init pref widget');
+export default class EasyScreenCastPreferences extends ExtensionPreferences {
+    /**
+     * @param {Adw.PreferencesWindow} window preferences window?
+     * @returns {EasyScreenCastSettingsWidget}
+     */
+    fillPreferencesWindow(window) {
+        window._settings = this.getSettings();
 
-    let widget = new EasyScreenCastSettingsWidget();
+        Lib.TalkativeLog('-^-Init pref widget');
 
-    if (!widget._isGtk4()) {
-        widget.show_all();
+        const page = new Adw.PreferencesPage();
+
+        const group = new Adw.PreferencesGroup({
+            title: _('EasyScreenCast'),
+        });
+        page.add(group);
+
+        const widget = new EasyScreenCastSettingsWidget(this);
+        group.add(widget);
+
+        window.add(page);
     }
-
-    return widget;
 }
